h1,
h2,
p {
  font-family: 'Helvetica', sans-serif;
  text-align: center;
}

img {
  display: block;
  margin-left: auto;
  margin-right: auto;
}

h1,
h2 {
  font-weight: 900;
}

p {
  font-weight: 300;
}

.actual,
.setpoint {
  font-size: 200%;
}

.footer {
  font-size: 12px;
}

.login-body {
  background: #fff;
}

.cell-table {
  display: table;
  height: 100%;
}

.cell {
  display: table-cell;
  vertical-align:middle;
}

.login-input,
.login-button {
  width: 150px;
}

.login-button {
  margin: 0;
}

.login-img {
  width: 150px;
  margin-bottom: 25px;
}
